COMPMID-1601: Graph examples segfaulting on some platform when gles=1

Makes the graph to setup and initialize only the backends used as some
platform have issues when GLES backend get initialized but not used.

Change-Id: Icf88675ffd8c2997e54a68baabfbbce241b0712c
Signed-off-by: Georgios Pinitas <georgios.pinitas@arm.com>
Reviewed-on: https://review.mlplatform.org/745
Tested-by: Arm Jenkins <bsgcomp@arm.com>
Reviewed-by: Giuseppe Rossini <giuseppe.rossini@arm.com>
diff --git a/arm_compute/graph/Utils.h b/arm_compute/graph/Utils.h
index 1a0509b..4ffccec 100644
--- a/arm_compute/graph/Utils.h
+++ b/arm_compute/graph/Utils.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018 ARM Limited.
+ * Copyright (c) 2018-2019 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -89,11 +89,12 @@
  * @return A PassManager with default mutating passes
  */
 PassManager create_default_pass_manager(Target target);
-/** Default setups the graph context if not done manually
+/** Setups requested backend context if it exists, is supported and hasn't been initialized already.
  *
  * @param[in,out] ctx Graph Context
  */
-void setup_default_graph_context(GraphContext &ctx);
+void setup_requested_backend_context(GraphContext &ctx, Target target);
 /** Default releases the graph context if not done manually
  *
  * @param[in,out] ctx Graph Context
@@ -89,11 +89,12 @@
  *
- * @param[in,out] ctx Graph Context
+ * @param[in,out] ctx    Graph Context.
+ * @param[in]     target Target to setup the backend for.
  */